import click
import kolore.palette as palette


@click.command()
@click.argument('filename')
@click.option('--output', help='path of the generated file', default='./palette.png')
@click.option('--from', 'from_', help='format of the input file', hidden=True)
@click.option('--to', help='format of output file', hidden=True)
@click.option('--width', default=400, type=int, help="image width size in pixels")
@click.option('--height', default=200, type=int, help="image height size in pixels")
def parse(filename: str, output: str, from_: str, to: str, width: int, height: int):
    palette.create(width, height, filename, output)



from zipfile import ZipFile
import os
import xml.etree.ElementTree as ET
from PIL import Image, ImageDraw
import tempfile


def create(width: int, height: int, path: str, output: str):
    colors = get_colors(path)
    save(width, height, colors, output)

def get_colors(path: str) -> [str]:
    with tempfile.TemporaryDirectory() as tmp_dir:
        with ZipFile(path, 'r') as zipObj:
            zipObj.extractall(tmp_dir)

            tree = ET.parse(f'{tmp_dir}/colorset.xml')
            root = tree.getroot()
            colors = []
            for child in root:
                rgb = child[0].attrib
                r = int(float(rgb['r']) * 255)
                g = int(float(rgb['g']) * 255)
                b = int(float(rgb['b']) * 255)
                colors.append(f'#{r:02x}{g:02x}{b:02x}')

    return colors

def save(width: int, height: int, colors: [str], output: str):
    img = Image.new('RGB', (width, height))
    draw = ImageDraw.Draw(img)
    num_colors = len(colors)
    color_width = width / num_colors
    for i, color in enumerate(colors):
        draw.rectangle([(color_width * i, 0), (color_width * (i + 1), height)], fill=color)
    
    img.save(output)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['kolore']

package_data = \
{'': ['*']}

install_requires = \
['Pillow>=8.1.0,<9.0.0', 'click>=7.1.2,<8.0.0']

entry_points = \
{'console_scripts': ['kolore = kolore.cli:parse']}

setup_kwargs = {
    'name': 'kolore',
    'version': '0.1.11',
    'description': 'A small cli utility to convert krita palette files into png images',
    'long_description': '# Kolore\n\nA small cli utility to convert krita palette files into png images.\n\n![Krita palette](palette_Demo.png)\n\n## Install\n\n`pip install kolore`\n\n## Usage\n\nTo create a palette, simply type\n\n`kolore palette.kpl`\n\nBy default the file will be called `palette.png`, but you can specify another name as well\n\n`kolore palette.kpl --output result.png`\n\nYou can also set the size of the generated image\n\n`kolore palette.kpl --output result.png --width 200 --height 100`\n\nGet general help with\n\n`kolore --help`',
    'author': 'AlvarBer',
    'author_email': 'git@alvarber.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://gitlab.com/AlvarBer/kolore',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
